import{P as r}from"./Passwordless.5d103398.js";import{d as a,ex as d,b as i,c as f,e as s,eq as c,t as _}from"./registerWidgets.751c4cc6.js";import{M as m}from"./member.51c4084d.js";import{W as p}from"./WidgetsFrame.5ca14e96.js";import"./CircularLoading.7ae0ffc2.js";import"./lottie.2da9cd67.js";import"./icons.839289ff.js";import"./passwordlessManager.8b22003c.js";import"./pubsub.87f27d54.js";import"./storage.fbef8aee.js";import"./gateway.a29f1b8a.js";import"./activeRecord.91f4e05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="4249295f-c7b7-4a9e-b6f6-6faf9dbddd86",e._sentryDebugIdIdentifier="sentry-dbid-4249295f-c7b7-4a9e-b6f6-6faf9dbddd86")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=d();async function t(n){await m.login(),o.push({name:"home"})}return(n,b)=>(i(),f("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:c(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const C=_(u,[["__scopeId","data-v-0e3dc783"]]);export{C as default};
//# sourceMappingURL=Login.48ae9cfd.js.map
