import"./registerWidgets.751c4cc6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="279927fb-5c03-4953-9cc2-60646d0dc87f",r._sentryDebugIdIdentifier="sentry-dbid-279927fb-5c03-4953-9cc2-60646d0dc87f")}catch{}})();class c{static get(e){try{const t=localStorage.getItem(e);return t&&JSON.parse(t)}catch{return null}}static set(e,t){localStorage.setItem(e,JSON.stringify(t))}static pop(e){const t=c.get(e);return c.remove(e),t}static remove(e){localStorage.removeItem(e)}}export{c as S};
//# sourceMappingURL=storage.fbef8aee.js.map
