import{u as a}from"./icons.839289ff.js";import{d as c,a as r,b as i,c as d,e as _,bu as f,bh as l,t as u}from"./registerWidgets.751c4cc6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="cbb55258-1d43-4c65-9cee-fe5ff7810024",e._sentryDebugIdIdentifier="sentry-dbid-cbb55258-1d43-4c65-9cee-fe5ff7810024")}catch{}})();const b=c({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const s=r("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(s,{class:"icon",path:f(a),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.b97fc7df.js.map
