import{S as c}from"./Sidebar.e41ef01d.js";import{N as m}from"./Navbar.8e2ae648.js";import{C as p,D as l,E as d}from"./icons.839289ff.js";import{d as u,ey as b,F as _,a as g,b as f,c as v,e as t,er as y,bw as z,t as w}from"./registerWidgets.751c4cc6.js";import{a as h}from"./asyncComputed.4ba8b2d8.js";import"./gateway.a29f1b8a.js";import{O as I}from"./organization.b2a124d1.js";import"./index.1677387f.js";import"./Tooltip.bd357a7a.js";import"./logo.084e5d7c.js";import"./passwordlessManager.8b22003c.js";import"./pubsub.87f27d54.js";import"./storage.fbef8aee.js";import"./activeRecord.91f4e05e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="731a9284-73b8-4343-b49c-210920199573",e._sentryDebugIdIdentifier="sentry-dbid-731a9284-73b8-4343-b49c-210920199573")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=b().params.organizationId,{result:o}=h(()=>I.get(n)),r=_(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:d,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=g("router-view");return f(),v(z,null,[t(m,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const G=w(D,[["__scopeId","data-v-51ce7239"]]);export{G as default};
//# sourceMappingURL=Organization.affa0c11.js.map
