import{t as o,a as r,b as i,u as c,f as p,g as d,_,h as u,k as l,T as h,P as f,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.751c4cc6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8714a63d-1a85-4605-819a-5b9ebfe964e4",e._sentryDebugIdIdentifier="sentry-dbid-8714a63d-1a85-4605-819a-5b9ebfe964e4")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.cbe5b3c1.js"),["assets/Player.cbe5b3c1.js","assets/index.35c304ed.js","assets/registerWidgets.751c4cc6.js","assets/registerWidgets.efc6a450.css","assets/uuid.e6796fb6.js","assets/broker.8bfd44f6.js","assets/passwordlessManager.8b22003c.js","assets/pubsub.87f27d54.js","assets/storage.fbef8aee.js","assets/Passwordless.5d103398.js","assets/CircularLoading.7ae0ffc2.js","assets/lottie.2da9cd67.js","assets/CircularLoading.f81b57b4.css","assets/icons.839289ff.js","assets/Passwordless.86ac0c56.css","assets/executeJs.264e8788.js","assets/PlayerNavbar.5bbcffdf.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.2317232c.js","assets/Steps.998aa76d.css","assets/Modal.2619bb1d.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.5ca14e96.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.f5e4856d.js","assets/broker.a17a9f70.css","assets/DashPlayer.00e50aa1.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.4ba8b2d8.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>l(x)});h.init(),D.init(),e.use(a),e.use(f),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.8ba15dd0.js.map
