import{d as u,ey as b,F as f,b as y,u as g,bu as _}from"./registerWidgets.751c4cc6.js";import{a as w}from"./asyncComputed.4ba8b2d8.js";import"./gateway.a29f1b8a.js";import{M as s}from"./member.51c4084d.js";import"./index.1677387f.js";import{C as I}from"./CrudView.55a91fc3.js";import"./passwordlessManager.8b22003c.js";import"./pubsub.87f27d54.js";import"./storage.fbef8aee.js";import"./activeRecord.91f4e05e.js";import"./DropdownMenu.3730f8d7.js";import"./Modal.2619bb1d.js";import"./LoadingIndicator.e1d41754.js";import"./lottie.2da9cd67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3b26d1e9-8e0a-4536-9e19-cb0ff40cc7a5",e._sentryDebugIdIdentifier="sentry-dbid-3b26d1e9-8e0a-4536-9e19-cb0ff40cc7a5")}catch{}})();const N=u({__name:"Members",setup(e){const o=b().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(o,t.email),d()},{loading:l,result:c,refetch:d}=w(()=>s.list(o)),p=f(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=c.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{N as default};
//# sourceMappingURL=Members.3b139f93.js.map
