import{D as d,F as t}from"./registerWidgets.751c4cc6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="9b915795-f6e1-4dc6-89c4-c2b2ac153bc0",r._sentryDebugIdIdentifier="sentry-dbid-9b915795-f6e1-4dc6-89c4-c2b2ac153bc0")}catch{}})();const i=r=>{const e=d({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),s=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(s)};o();const u=t(()=>e.value.loading),a=t(()=>e.value.result),c=t(()=>e.value.error);return{loading:u,result:a,error:c,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.4ba8b2d8.js.map
